@@ -36,11 +36,15 @@ if not ENV_FILE.exists():
     EXTERNAL_UNMANAGED_PASSWORD = os.getenv("PYLAV__EXTERNAL_UNMANAGED_PASSWORD")
     EXTERNAL_UNMANAGED_SSL = bool(int(os.getenv("PYLAV__EXTERNAL_UNMANAGED_SSL", 0)))
 
-    TASK_TIMER_UPDATE_BUNDLED_PLAYLISTS = max(int(os.getenv("PYLAV__TASK_TIMER_UPDATE_BUNDLED_PLAYLISTS", "1")), 1)
-    TASK_TIMER_UPDATE_BUNDLED_EXTERNAL_PLAYLISTS = max(
-        int(os.getenv("PYLAV__TASK_TIMER_UPDATE_BUNDLED_EXTERNAL_PLAYLISTS", "7")), 7
+    TASK_TIMER_UPDATE_BUNDLED_PLAYLISTS_DAYS = max(
+        int(os.getenv("PYLAV__TASK_TIMER_UPDATE_BUNDLED_PLAYLISTS_DAYS", "1")), 1
+    )
+    TASK_TIMER_UPDATE_BUNDLED_EXTERNAL_PLAYLISTS_DAYS = max(
+        int(os.getenv("PYLAV__TASK_TIMER_UPDATE_BUNDLED_EXTERNAL_PLAYLISTS_DAYS", "7")), 7
+    )
+    TASK_TIMER_UPDATE_EXTERNAL_PLAYLISTS_DAYS = max(
+        int(os.getenv("PYLAV__TASK_TIMER_UPDATE_EXTERNAL_PLAYLISTS_DAYS", "7")), 7
     )
-    TASK_TIMER_UPDATE_EXTERNAL_PLAYLISTS = max(int(os.getenv("PYLAV__TASK_TIMER_UPDATE_EXTERNAL_PLAYLISTS", "7")), 7)
 
     data = {
         "PYLAV__POSTGRES_PORT": POSTGRES_PORT,
@@ -57,9 +61,9 @@ if not ENV_FILE.exists():
         "PYLAV__EXTERNAL_UNMANAGED_PORT": EXTERNAL_UNMANAGED_PORT,
         "PYLAV__EXTERNAL_UNMANAGED_PASSWORD": EXTERNAL_UNMANAGED_PASSWORD,
         "PYLAV__EXTERNAL_UNMANAGED_SSL": EXTERNAL_UNMANAGED_SSL,
-        "PYLAV__TASK_TIMER_UPDATE_BUNDLED_PLAYLISTS": TASK_TIMER_UPDATE_BUNDLED_PLAYLISTS,
-        "PYLAV__TASK_TIMER_UPDATE_BUNDLED_EXTERNAL_PLAYLISTS": TASK_TIMER_UPDATE_BUNDLED_EXTERNAL_PLAYLISTS,
-        "PYLAV__TASK_TIMER_UPDATE_EXTERNAL_PLAYLISTS": TASK_TIMER_UPDATE_EXTERNAL_PLAYLISTS,
+        "PYLAV__TASK_TIMER_UPDATE_BUNDLED_PLAYLISTS_DAYS": TASK_TIMER_UPDATE_BUNDLED_PLAYLISTS_DAYS,
+        "PYLAV__TASK_TIMER_UPDATE_BUNDLED_EXTERNAL_PLAYLISTS_DAYS": TASK_TIMER_UPDATE_BUNDLED_EXTERNAL_PLAYLISTS_DAYS,
+        "PYLAV__TASK_TIMER_UPDATE_EXTERNAL_PLAYLISTS_DAYS": TASK_TIMER_UPDATE_EXTERNAL_PLAYLISTS_DAYS,
     }
     with ENV_FILE.open(mode="w") as file:
         LOGGER.debug("Creating %s with the following content: %r", ENV_FILE, data)
@@ -128,29 +132,33 @@ else:
             EXTERNAL_UNMANAGED_SSL = bool(int(os.getenv("PYLAV__EXTERNAL_UNMANAGED_SSL", "0")))
             data_new["PYLAV__EXTERNAL_UNMANAGED_SSL"] = EXTERNAL_UNMANAGED_SSL
 
-        if (TASK_TIMER_UPDATE_BUNDLED_PLAYLISTS := data.get("PYLAV__TASK_TIMER_UPDATE_BUNDLED_PLAYLISTS")) is None:
-            TASK_TIMER_UPDATE_BUNDLED_PLAYLISTS = max(
-                int(os.getenv("PYLAV__TASK_TIMER_UPDATE_BUNDLED_PLAYLISTS", "1")), 1
+        if (
+            TASK_TIMER_UPDATE_BUNDLED_PLAYLISTS_DAYS := data.get("PYLAV__TASK_TIMER_UPDATE_BUNDLED_PLAYLISTS_DAYS")
+        ) is None:
+            TASK_TIMER_UPDATE_BUNDLED_PLAYLISTS_DAYS = max(
+                int(os.getenv("PYLAV__TASK_TIMER_UPDATE_BUNDLED_PLAYLISTS_DAYS", "1")), 1
             )
-            data_new["PYLAV__TASK_TIMER_UPDATE_BUNDLED_PLAYLISTS"] = TASK_TIMER_UPDATE_BUNDLED_PLAYLISTS
+            data_new["PYLAV__TASK_TIMER_UPDATE_BUNDLED_PLAYLISTS_DAYS"] = TASK_TIMER_UPDATE_BUNDLED_PLAYLISTS_DAYS
 
         if (
-            TASK_TIMER_UPDATE_BUNDLED_EXTERNAL_PLAYLISTS := data.get(
-                "PYLAV__TASK_TIMER_UPDATE_BUNDLED_EXTERNAL_PLAYLISTS"
+            TASK_TIMER_UPDATE_BUNDLED_EXTERNAL_PLAYLISTS_DAYS := data.get(
+                "PYLAV__TASK_TIMER_UPDATE_BUNDLED_EXTERNAL_PLAYLISTS_DAYS"
             )
         ) is None:
-            TASK_TIMER_UPDATE_BUNDLED_EXTERNAL_PLAYLISTS = max(
-                int(os.getenv("PYLAV__TASK_TIMER_UPDATE_BUNDLED_EXTERNAL_PLAYLISTS", "7")), 7
+            TASK_TIMER_UPDATE_BUNDLED_EXTERNAL_PLAYLISTS_DAYS = max(
+                int(os.getenv("PYLAV__TASK_TIMER_UPDATE_BUNDLED_EXTERNAL_PLAYLISTS_DAYS", "7")), 7
             )
             data_new[
-                "PYLAV__TASK_TIMER_UPDATE_BUNDLED_EXTERNAL_PLAYLISTS"
-            ] = TASK_TIMER_UPDATE_BUNDLED_EXTERNAL_PLAYLISTS
+                "PYLAV__TASK_TIMER_UPDATE_BUNDLED_EXTERNAL_PLAYLISTS_DAYS"
+            ] = TASK_TIMER_UPDATE_BUNDLED_EXTERNAL_PLAYLISTS_DAYS
 
-        if (TASK_TIMER_UPDATE_EXTERNAL_PLAYLISTS := data.get("PYLAV__TASK_TIMER_UPDATE_EXTERNAL_PLAYLISTS")) is None:
-            TASK_TIMER_UPDATE_EXTERNAL_PLAYLISTS = max(
-                int(os.getenv("PYLAV__TASK_TIMER_UPDATE_EXTERNAL_PLAYLISTS", "7")), 7
+        if (
+            TASK_TIMER_UPDATE_EXTERNAL_PLAYLISTS_DAYS := data.get("PYLAV__TASK_TIMER_UPDATE_EXTERNAL_PLAYLISTS_DAYS")
+        ) is None:
+            TASK_TIMER_UPDATE_EXTERNAL_PLAYLISTS_DAYS = max(
+                int(os.getenv("PYLAV__TASK_TIMER_UPDATE_EXTERNAL_PLAYLISTS_DAYS", "7")), 7
             )
-            data_new["PYLAV__TASK_TIMER_UPDATE_EXTERNAL_PLAYLISTS"] = TASK_TIMER_UPDATE_EXTERNAL_PLAYLISTS
+            data_new["PYLAV__TASK_TIMER_UPDATE_EXTERNAL_PLAYLISTS_DAYS"] = TASK_TIMER_UPDATE_EXTERNAL_PLAYLISTS_DAYS
 
     if DeepDiff(data, data_new, ignore_order=True):
         with ENV_FILE.open(mode="w") as file:
